==> katapult-trinity-3.5.13.2.tar.xz: katapult-trinity-3.5.13.2/katapult/common/katapultcatalog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include "katapultcatalog.moc"
#include "katapultcatalog.h"
#include "match.h"

KatapultCatalog::KatapultCatalog()
{
	_bestMatch = Match();
	_status = 0;
	_query = "";
}


KatapultCatalog::~KatapultCatalog()
{
}

void KatapultCatalog::queryChanged()
{
}

void KatapultCatalog::initialize()
{
}

void KatapultCatalog::setQuery(TQString _query)
{
	if(this->_query != _query) {
		this->_query = _query;
		queryChanged();
	}
}

void KatapultCatalog::setStatus(int _status)
{
	this->_status = _status;
}

void KatapultCatalog::setBestMatch(Match _bestMatch)
{
	this->_bestMatch = _bestMatch;
}

TQString KatapultCatalog::query() const
{
	return _query;
}

int KatapultCatalog::status() const
{
	return _status;
}

Match KatapultCatalog::bestMatch() const
{
	return _bestMatch;
}

void KatapultCatalog::readSettings(KConfigBase *)
{
}

void KatapultCatalog::writeSettings(KConfigBase *)
{
}

TQWidget * KatapultCatalog::configure()
{
	return 0;
}

==> katapult-trinity-14.0.13.tar.xz: katapult-trinity-14.0.13/katapult/common/katapultcatalog.cpp <==
/***************************************************************************
 *   Copyright (C) 2005 by Joe Ferris                                      *
 *   jferris@optimistictech.com                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/

#include "katapultcatalog.moc"
#include "katapultcatalog.h"
#include "match.h"

KatapultCatalog::KatapultCatalog()
{
	_bestMatch = Match();
	_status = 0;
	_query = "";
}


KatapultCatalog::~KatapultCatalog()
{
}

void KatapultCatalog::queryChanged()
{
}

void KatapultCatalog::initialize()
{
}

void KatapultCatalog::setQuery(TQString _query)
{
	if(this->_query != _query) {
		this->_query = _query;
		queryChanged();
	}
}

void KatapultCatalog::setStatus(int _status)
{
	this->_status = _status;
}

void KatapultCatalog::setBestMatch(Match _bestMatch)
{
	this->_bestMatch = _bestMatch;
}

TQString KatapultCatalog::query() const
{
	return _query;
}

int KatapultCatalog::status() const
{
	return _status;
}

Match KatapultCatalog::bestMatch() const
{
	return _bestMatch;
}

void KatapultCatalog::readSettings(TDEConfigBase *)
{
}

void KatapultCatalog::writeSettings(TDEConfigBase *)
{
}

TQWidget * KatapultCatalog::configure()
{
	return 0;
}
